@@ -6,7 +6,7 @@
     <message>
         <location filename="../mainwindow.ui" line="20"/>
         <source>MX Boot Repair</source>
-        <translation type="unfinished">MX ማስነሻ መጠገኛ</translation>
+        <translation>MX ማስነሻ መጠገኛ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="39"/>
@@ -16,12 +16,12 @@
     <message>
         <location filename="../mainwindow.ui" line="58"/>
         <source>What would you like to do?</source>
-        <translation type="unfinished">እርስዎ ምን መስራት ነው የሚፈልጉት?</translation>
+        <translation>እርስዎ ምን መስራት ነው የሚፈልጉት?</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="79"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
-        <translation type="unfinished">Backup MBR or PBR (legacy boot only)</translation>
+        <translation>Backup MBR or PBR (legacy boot only)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="86"/>
@@ -31,57 +31,57 @@
     <message>
         <location filename="../mainwindow.ui" line="96"/>
         <source>Repair GRUB configuration file</source>
-        <translation type="unfinished">የ GRUB ማሰናጃ ፋይል መጠገኛ</translation>
+        <translation>የ GRUB ማሰናጃ ፋይል መጠገኛ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="103"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
-        <translation type="unfinished"></translation>
+        <translation>እንደ ነበር መመሻ MBR ወይንም PBR ከ ተተኪ ውስጥ (legacy boot only)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="136"/>
         <location filename="../mainwindow.cpp" line="485"/>
         <source>Select Boot Method</source>
-        <translation type="unfinished">የ ማስነሻ ዘዴ ይምረጡ</translation>
+        <translation>የ ማስነሻ ዘዴ ይምረጡ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="154"/>
         <source>Master Boot Record</source>
-        <translation type="unfinished">ዋናው የ ማስነሻ መዝገብ</translation>
+        <translation>ዋናው የ ማስነሻ መዝገብ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="157"/>
         <source>MBR</source>
-        <translation type="unfinished">MBR</translation>
+        <translation>MBR</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="160"/>
         <location filename="../mainwindow.ui" line="430"/>
         <source>Alt+B</source>
-        <translation type="unfinished">Alt+B</translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="182"/>
         <source>Root (Partition Boot Record)</source>
-        <translation type="unfinished">Root (ክፍልፋይ የ ማስነሻ መዝገብ)</translation>
+        <translation>Root (ክፍልፋይ የ ማስነሻ መዝገብ)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="185"/>
         <location filename="../mainwindow.cpp" line="488"/>
         <source>root</source>
-        <translation type="unfinished">root</translation>
+        <translation>root</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="236"/>
         <location filename="../mainwindow.cpp" line="487"/>
         <source>Install on:</source>
-        <translation type="unfinished">መግጠሚያ በ:</translation>
+        <translation>መግጠሚያ በ:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="255"/>
         <location filename="../mainwindow.cpp" line="486"/>
         <source>Location:</source>
-        <translation type="unfinished">አካባቢ:</translation>
+        <translation>አካባቢ:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="277"/>
@@ -92,63 +92,63 @@
     <message>
         <location filename="../mainwindow.ui" line="290"/>
         <source>EFI System Partition</source>
-        <translation type="unfinished">EFI System Partition</translation>
+        <translation>EFI System Partition</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="293"/>
         <source>ESP</source>
-        <translation type="unfinished">ESP</translation>
+        <translation>ESP</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="420"/>
         <source>About this application</source>
-        <translation type="unfinished">ስለዚህ መተግበሪያ</translation>
+        <translation>ስለዚህ መተግበሪያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="423"/>
         <source>About...</source>
-        <translation type="unfinished">ስለ...</translation>
+        <translation>ስለ...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="472"/>
         <source>Display help </source>
-        <translation type="unfinished">እርዳታ ማሳያ</translation>
+        <translation>እርዳታ ማሳያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="475"/>
         <source>Help</source>
-        <translation type="unfinished">እርዳታ</translation>
+        <translation>እርዳታ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="482"/>
         <source>Alt+H</source>
-        <translation type="unfinished">Alt+H</translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="523"/>
         <source>Cancel any changes then quit</source>
-        <translation type="unfinished">ማንኛውንም ለውጥ መሰረዣ እና ማጥፊያ</translation>
+        <translation>ማንኛውንም ለውጥ መሰረዣ እና ማጥፊያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="526"/>
         <source>Cancel</source>
-        <translation type="unfinished">መሰረዣ</translation>
+        <translation>መሰረዣ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="533"/>
         <source>Alt+N</source>
-        <translation type="unfinished">Alt+N</translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="552"/>
         <source>Apply any changes</source>
-        <translation type="unfinished">ማንኛውንም ለውጥ መፈጸሚያ</translation>
+        <translation>ማንኛውንም ለውጥ መፈጸሚያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="555"/>
         <location filename="../mainwindow.cpp" line="70"/>
         <source>Apply</source>
-        <translation type="unfinished">መፈጸሚያ</translation>
+        <translation>መፈጸሚያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="86"/>
@@ -165,22 +165,15 @@
         <location filename="../mainwindow.cpp" line="534"/>
         <location filename="../mainwindow.cpp" line="597"/>
         <source>Error</source>
-        <translation type="unfinished">ስህተት</translation>
-    </message>
-    <message>
-        <source>Could not mount </source>
-        <translation type="obsolete">መጫን አልተቻለም</translation>
-    </message>
-    <message>
-        <source> on /boot/efi</source>
-        <translation type="obsolete"> on /boot/efi</translation>
+        <translation>ስህተት</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="119"/>
         <location filename="../mainwindow.cpp" line="204"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
-        <translation type="unfinished"></translation>
+        <translation>የ chroot አካባቢ ማሰናዳት አልተቻለም
+እባከዎን በ ድጋሚ-ይመርምሩ የ ተመረጠውን አካባቢ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="179"/>
@@ -195,24 +188,24 @@ Please double-check the selected location.</source>
     <message>
         <location filename="../mainwindow.cpp" line="287"/>
         <source>Warning</source>
-        <translation type="unfinished">ማስጠንቀቂያ</translation>
+        <translation>ማስጠንቀቂያ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="288"/>
         <source>You are going to write the content of </source>
-        <translation type="unfinished"></translation>
+        <translation>እርስዎ ይዞታውን ሊጽፉ ነው የ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="288"/>
         <source> to </source>
-        <translation type="unfinished">ለ</translation>
+        <translation>ለ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="288"/>
         <source>
 
 Are you sure?</source>
-        <translation type="unfinished">
+        <translation>
 
 እርስዎ እርግጠኛ ነዎት?</translation>
     </message>
@@ -226,10 +219,6 @@ Are you sure?</source>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Select /boot location:</source>
-        <translation type="obsolete">ይምረጡ /የ ማስነሻ አካባቢ</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="348"/>
         <source>Select %1 location:</source>
@@ -238,12 +227,12 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="372"/>
         <source>Back</source>
-        <translation type="unfinished">ወደ ኋላ</translation>
+        <translation>ወደ ኋላ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="388"/>
         <source>Success</source>
-        <translation type="unfinished">ተሳክቷል</translation>
+        <translation>ተሳክቷል</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="389"/>
@@ -253,7 +242,7 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="395"/>
         <source>Process finished. Errors have occurred.</source>
-        <translation type="unfinished"></translation>
+        <translation>ሂደቱ ተፈጽሟል: ስህተት ተፈጥሯል</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="412"/>
@@ -283,18 +272,18 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="525"/>
         <source>Select backup file name</source>
-        <translation type="unfinished">የ ተተኪ ፋይል ስም ይምረጡ</translation>
+        <translation>የ ተተኪ ፋይል ስም ይምረጡ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="527"/>
         <location filename="../mainwindow.cpp" line="534"/>
         <source>No file was selected.</source>
-        <translation type="unfinished">ምንም ፋይል አልተመረጠም:</translation>
+        <translation>ምንም ፋይል አልተመረጠም:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="532"/>
         <source>Select MBR or PBR backup file</source>
-        <translation type="unfinished"></translation>
+        <translation>የ MBR ወይንም PBR ተተኪ ፋይል ይምረጡ</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="552"/>
@@ -304,7 +293,7 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="553"/>
         <source>Version: </source>
-        <translation type="unfinished">እትም</translation>
+        <translation>እትም</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="554"/>
@@ -314,7 +303,7 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="556"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">የ ቅጂ መብት (c) MX Linux</translation>
+        <translation>የ ቅጂ መብት (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="557"/>
@@ -334,15 +323,10 @@ Are you sure?</source>
 </context>
 <context>
     <name>QApplication</name>
-    <message>
-        <location filename="../main.cpp" line="64"/>
-        <source>You must run this program as root.</source>
-        <translation>ይህን ፕሮግራም እንደ root ማስኬድ አለብዎት</translation>
-    </message>
     <message>
         <location filename="../about.cpp" line="32"/>
         <source>License</source>
-        <translation type="unfinished">ፍቃድ</translation>
+        <translation>ፍቃድ</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="33"/>
@@ -353,175 +337,17 @@ Are you sure?</source>
     <message>
         <location filename="../about.cpp" line="34"/>
         <source>Cancel</source>
-        <translation type="unfinished">መሰረዣ</translation>
+        <translation>መሰረዣ</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;መዝጊያ</translation>
-    </message>
-</context>
-<context>
-    <name>mxbootrepair</name>
-    <message>
-        <source>MX Boot Repair</source>
-        <translation type="vanished">MX ማስነሻ መጠገኛ</translation>
+        <translation>&amp;መዝጊያ</translation>
     </message>
     <message>
-        <source>What would you like to do?</source>
-        <translation type="vanished">እርስዎ ምን መስራት ነው የሚፈልጉት?</translation>
-    </message>
-    <message>
-        <source>Backup MBR or PBR (legacy boot only)</source>
-        <translation type="vanished">Backup MBR or PBR (legacy boot only)</translation>
-    </message>
-    <message>
-        <source>Repair GRUB configuration file</source>
-        <translation type="vanished">የ GRUB ማሰናጃ ፋይል መጠገኛ</translation>
-    </message>
-    <message>
-        <source>Select Boot Method</source>
-        <translation type="vanished">የ ማስነሻ ዘዴ ይምረጡ</translation>
-    </message>
-    <message>
-        <source>Master Boot Record</source>
-        <translation type="vanished">ዋናው የ ማስነሻ መዝገብ</translation>
-    </message>
-    <message>
-        <source>MBR</source>
-        <translation type="vanished">MBR</translation>
-    </message>
-    <message>
-        <source>Alt+B</source>
-        <translation type="vanished">Alt+B</translation>
-    </message>
-    <message>
-        <source>Root (Partition Boot Record)</source>
-        <translation type="vanished">Root (ክፍልፋይ የ ማስነሻ መዝገብ)</translation>
-    </message>
-    <message>
-        <source>root</source>
-        <translation type="vanished">root</translation>
-    </message>
-    <message>
-        <source>Install on:</source>
-        <translation type="vanished">መግጠሚያ በ:</translation>
-    </message>
-    <message>
-        <source>Location:</source>
-        <translation type="vanished">አካባቢ:</translation>
-    </message>
-    <message>
-        <source>Select /boot location:</source>
-        <translation type="vanished">ይምረጡ /የ ማስነሻ አካባቢ</translation>
-    </message>
-    <message>
-        <source>EFI System Partition</source>
-        <translation type="vanished">EFI System Partition</translation>
-    </message>
-    <message>
-        <source>ESP</source>
-        <translation type="vanished">ESP</translation>
-    </message>
-    <message>
-        <source>About this application</source>
-        <translation type="vanished">ስለዚህ መተግበሪያ</translation>
-    </message>
-    <message>
-        <source>About...</source>
-        <translation type="vanished">ስለ...</translation>
-    </message>
-    <message>
-        <source>Display help </source>
-        <translation type="vanished">እርዳታ ማሳያ</translation>
-    </message>
-    <message>
-        <source>Help</source>
-        <translation type="vanished">እርዳታ</translation>
-    </message>
-    <message>
-        <source>Alt+H</source>
-        <translation type="vanished">Alt+H</translation>
-    </message>
-    <message>
-        <source>Cancel any changes then quit</source>
-        <translation type="vanished">ማንኛውንም ለውጥ መሰረዣ እና ማጥፊያ</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">መሰረዣ</translation>
-    </message>
-    <message>
-        <source>Alt+N</source>
-        <translation type="vanished">Alt+N</translation>
-    </message>
-    <message>
-        <source>Apply any changes</source>
-        <translation type="vanished">ማንኛውንም ለውጥ መፈጸሚያ</translation>
-    </message>
-    <message>
-        <source>Apply</source>
-        <translation type="vanished">መፈጸሚያ</translation>
-    </message>
-    <message>
-        <source>Error</source>
-        <translation type="vanished">ስህተት</translation>
-    </message>
-    <message>
-        <source>Could not mount </source>
-        <translation type="vanished">መጫን አልተቻለም</translation>
-    </message>
-    <message>
-        <source> on /boot/efi</source>
-        <translation type="vanished"> on /boot/efi</translation>
-    </message>
-    <message>
-        <source>Warning</source>
-        <translation type="vanished">ማስጠንቀቂያ</translation>
-    </message>
-    <message>
-        <source> to </source>
-        <translation type="vanished">ለ</translation>
-    </message>
-    <message>
-        <source>
-
-Are you sure?</source>
-        <translation type="vanished">
-
-እርስዎ እርግጠኛ ነዎት?</translation>
-    </message>
-    <message>
-        <source>Success</source>
-        <translation type="vanished">ተሳክቷል</translation>
-    </message>
-    <message>
-        <source>Back</source>
-        <translation type="vanished">ወደ ኋላ</translation>
-    </message>
-    <message>
-        <source>Select backup file name</source>
-        <translation type="vanished">የ ተተኪ ፋይል ስም ይምረጡ</translation>
-    </message>
-    <message>
-        <source>No file was selected.</source>
-        <translation type="vanished">ምንም ፋይል አልተመረጠም:</translation>
-    </message>
-    <message>
-        <source>Version: </source>
-        <translation type="vanished">እትም</translation>
-    </message>
-    <message>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">የ ቅጂ መብት (c) MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">ፍቃድ</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;መዝጊያ</translation>
+        <location filename="../main.cpp" line="64"/>
+        <source>You must run this program as root.</source>
+        <translation>ይህን ፕሮግራም እንደ root ማስኬድ አለብዎት</translation>
     </message>
 </context>
 </TS>
