@@ -58,7 +58,7 @@
         <location filename="../mainwindow.ui" line="160"/>
         <location filename="../mainwindow.ui" line="430"/>
         <source>Alt+B</source>
-        <translation type="unfinished">Alt+B</translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="182"/>
@@ -102,27 +102,27 @@
     <message>
         <location filename="../mainwindow.ui" line="420"/>
         <source>About this application</source>
-        <translation type="unfinished">Um þetta forrit</translation>
+        <translation>Um þetta forrit</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="423"/>
         <source>About...</source>
-        <translation type="unfinished">Um hugbúnaðinn...</translation>
+        <translation>Um hugbúnaðinn...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="472"/>
         <source>Display help </source>
-        <translation type="unfinished">Birta hjálp</translation>
+        <translation>Birta hjálp</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="475"/>
         <source>Help</source>
-        <translation type="unfinished">Hjálp</translation>
+        <translation>Hjálp</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="482"/>
         <source>Alt+H</source>
-        <translation type="unfinished">Alt+H</translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="523"/>
@@ -132,12 +132,12 @@
     <message>
         <location filename="../mainwindow.ui" line="526"/>
         <source>Cancel</source>
-        <translation type="unfinished">Hætta við</translation>
+        <translation>Hætta við</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="533"/>
         <source>Alt+N</source>
-        <translation type="unfinished">Alt+N</translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="552"/>
@@ -148,7 +148,7 @@
         <location filename="../mainwindow.ui" line="555"/>
         <location filename="../mainwindow.cpp" line="70"/>
         <source>Apply</source>
-        <translation type="unfinished">Virkja</translation>
+        <translation>Virkja</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="86"/>
@@ -165,7 +165,7 @@
         <location filename="../mainwindow.cpp" line="534"/>
         <location filename="../mainwindow.cpp" line="597"/>
         <source>Error</source>
-        <translation type="unfinished">Villa</translation>
+        <translation>Villa</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="119"/>
@@ -187,7 +187,7 @@ Please double-check the selected location.</source>
     <message>
         <location filename="../mainwindow.cpp" line="287"/>
         <source>Warning</source>
-        <translation type="unfinished">Aðvörun</translation>
+        <translation>Aðvörun</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="288"/>
@@ -290,7 +290,7 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="553"/>
         <source>Version: </source>
-        <translation type="unfinished">Útgáfa:</translation>
+        <translation>Útgáfa:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="554"/>
@@ -300,7 +300,7 @@ Are you sure?</source>
     <message>
         <location filename="../mainwindow.cpp" line="556"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">Höfundarréttur (c) MX Linux</translation>
+        <translation>Höfundarréttur (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="557"/>
@@ -320,98 +320,31 @@ Are you sure?</source>
 </context>
 <context>
     <name>QApplication</name>
-    <message>
-        <location filename="../main.cpp" line="64"/>
-        <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../about.cpp" line="32"/>
         <source>License</source>
-        <translation type="unfinished">Notkunarleyfi</translation>
+        <translation>Notkunarleyfi</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="33"/>
         <location filename="../about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="unfinished">Breytingaskrá</translation>
+        <translation>Breytingaskrá</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="34"/>
         <source>Cancel</source>
-        <translation type="unfinished">Hætta við</translation>
+        <translation>Hætta við</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Loka</translation>
-    </message>
-</context>
-<context>
-    <name>mxbootrepair</name>
-    <message>
-        <source>Alt+B</source>
-        <translation type="vanished">Alt+B</translation>
+        <translation>&amp;Loka</translation>
     </message>
     <message>
-        <source>About this application</source>
-        <translation type="vanished">Um þetta forrit</translation>
-    </message>
-    <message>
-        <source>About...</source>
-        <translation type="vanished">Um hugbúnaðinn...</translation>
-    </message>
-    <message>
-        <source>Display help </source>
-        <translation type="vanished">Birta hjálp</translation>
-    </message>
-    <message>
-        <source>Help</source>
-        <translation type="vanished">Hjálp</translation>
-    </message>
-    <message>
-        <source>Alt+H</source>
-        <translation type="vanished">Alt+H</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">Hætta við</translation>
-    </message>
-    <message>
-        <source>Alt+N</source>
-        <translation type="vanished">Alt+N</translation>
-    </message>
-    <message>
-        <source>Apply</source>
-        <translation type="vanished">Virkja</translation>
-    </message>
-    <message>
-        <source>Error</source>
-        <translation type="vanished">Villa</translation>
-    </message>
-    <message>
-        <source>Warning</source>
-        <translation type="vanished">Aðvörun</translation>
-    </message>
-    <message>
-        <source>Version: </source>
-        <translation type="vanished">Útgáfa:</translation>
-    </message>
-    <message>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">Höfundarréttur (c) MX Linux</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Notkunarleyfi</translation>
-    </message>
-    <message>
-        <source>Changelog</source>
-        <translation type="vanished">Breytingaskrá</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Loka</translation>
+        <location filename="../main.cpp" line="64"/>
+        <source>You must run this program as root.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
